/* 
 * Copyright (c) 2022-2024 AccelByte Inc. All Rights Reserved
 * This is licensed software from AccelByte Inc, for limitations
 * and restrictions contact your company contract manager.
 */
/**
 * AUTO GENERATED
 */
import { Response, Validate } from '@accelbyte/sdk'
import { AxiosInstance, AxiosRequestConfig } from 'axios'
import { z } from 'zod'
import { UserProfileAdmin } from '../../generated-definitions/UserProfileAdmin.js'
import { UserProfileBulkRequest } from '../../generated-definitions/UserProfileBulkRequest.js'
import { UserProfileInfo } from '../../generated-definitions/UserProfileInfo.js'
import { UserProfilePrivateInfo } from '../../generated-definitions/UserProfilePrivateInfo.js'
import { UserProfilePublicInfoArray } from '../../generated-definitions/UserProfilePublicInfoArray.js'
import { UserProfileStatusUpdate } from '../../generated-definitions/UserProfileStatusUpdate.js'

export class UserProfileAdmin$ {
  // @ts-ignore
  // prettier-ignore
  constructor(private axiosInstance: AxiosInstance, private namespace: string, private useSchemaValidation = true) {}
  
  /**
   * Admin get user public profile by ids.&lt;br&gt;Other detail info: &lt;ul&gt;&lt;li&gt;&lt;i&gt;Required permission&lt;/i&gt;: resource=&lt;b&gt;&#34;ADMIN:NAMESPACE:{namespace}:PROFILE&#34;&lt;/b&gt;, action=2 &lt;b&gt;(GET)&lt;/b&gt;&lt;/li&gt;&lt;li&gt;&lt;i&gt;Action code&lt;/i&gt;: 11405&lt;/li&gt;&lt;li&gt;&lt;i&gt;Returns&lt;/i&gt;: user public profiles&lt;/li&gt;&lt;/ul&gt; 
   */
  createProfilePublic(data: UserProfileBulkRequest): Promise<Response<UserProfilePublicInfoArray>> {
    const params = {} as AxiosRequestConfig
    const url = '/basic/v1/admin/namespaces/{namespace}/profiles/public'.replace('{namespace}', this.namespace)     
    const resultPromise = this.axiosInstance.post(url, data, {params})

    return Validate.validateOrReturnResponse(this.useSchemaValidation, () => resultPromise, UserProfilePublicInfoArray, 'UserProfilePublicInfoArray')
  }
  
  /**
   * Get user profile by public id.&lt;br&gt;Other detail info: &lt;ul&gt;&lt;li&gt;&lt;i&gt;Returns&lt;/i&gt;: user profile info&lt;/li&gt;&lt;/ul&gt; 
   */
  getProfilesByPublicId( queryParams: {publicId: string | null}): Promise<Response<UserProfileInfo>> {
    const params = { ...queryParams} as AxiosRequestConfig
    const url = '/basic/v1/admin/namespaces/{namespace}/profiles/byPublicId'.replace('{namespace}', this.namespace)     
    const resultPromise = this.axiosInstance.get(url, {params})

    return Validate.validateOrReturnResponse(this.useSchemaValidation, () => resultPromise, UserProfileInfo, 'UserProfileInfo')
  }
  
  /**
   * Delete user profile.&lt;br&gt;Other detail info: &lt;ul&gt;&lt;li&gt;&lt;i&gt;Action code&lt;/i&gt;: 11407&lt;/li&gt;&lt;li&gt;&lt;i&gt;Returns&lt;/i&gt;: Delete user profile&lt;/li&gt;&lt;/ul&gt; 
   */
  deleteProfile_ByUserId(userId:string): Promise<Response<UserProfilePrivateInfo>> {
    const params = {} as AxiosRequestConfig
    const url = '/basic/v1/admin/namespaces/{namespace}/users/{userId}/profiles'.replace('{namespace}', this.namespace).replace('{userId}', userId)     
    const resultPromise = this.axiosInstance.delete(url, {params})

    return Validate.validateOrReturnResponse(this.useSchemaValidation, () => resultPromise, UserProfilePrivateInfo, 'UserProfilePrivateInfo')
  }
  
  /**
   * Get user profile.&lt;br&gt;Other detail info: &lt;ul&gt;&lt;li&gt;&lt;i&gt;Returns&lt;/i&gt;: user profile&lt;/li&gt;&lt;li&gt;&lt;i&gt;Action code&lt;/i&gt;: 11403&lt;/li&gt;&lt;/ul&gt; 
   */
  getProfiles_ByUserId(userId:string): Promise<Response<UserProfilePrivateInfo>> {
    const params = {} as AxiosRequestConfig
    const url = '/basic/v1/admin/namespaces/{namespace}/users/{userId}/profiles'.replace('{namespace}', this.namespace).replace('{userId}', userId)     
    const resultPromise = this.axiosInstance.get(url, {params})

    return Validate.validateOrReturnResponse(this.useSchemaValidation, () => resultPromise, UserProfilePrivateInfo, 'UserProfilePrivateInfo')
  }
  
  /**
   * Update user profile.&lt;br&gt;Other detail info: &lt;ul&gt;&lt;li&gt;&lt;i&gt;Action code&lt;/i&gt;: 11402&lt;/li&gt;&lt;li&gt;&lt;i&gt;Returns&lt;/i&gt;: Updated user profile&lt;/li&gt;&lt;/ul&gt; 
   */
  updateProfile_ByUserId(userId:string, data: UserProfileAdmin): Promise<Response<UserProfilePrivateInfo>> {
    const params = {} as AxiosRequestConfig
    const url = '/basic/v1/admin/namespaces/{namespace}/users/{userId}/profiles'.replace('{namespace}', this.namespace).replace('{userId}', userId)     
    const resultPromise = this.axiosInstance.put(url, data, {params})

    return Validate.validateOrReturnResponse(this.useSchemaValidation, () => resultPromise, UserProfilePrivateInfo, 'UserProfilePrivateInfo')
  }
  
  /**
   * Update user profile status.&lt;br&gt;Other detail info: &lt;ul&gt;&lt;li&gt;&lt;i&gt;Action code&lt;/i&gt;: 11406&lt;/li&gt;&lt;li&gt;&lt;i&gt;Returns&lt;/i&gt;: user profile&lt;/li&gt;&lt;/ul&gt; 
   */
  patchProfileStatus_ByUserId(userId:string, data: UserProfileStatusUpdate): Promise<Response<UserProfilePrivateInfo>> {
    const params = {} as AxiosRequestConfig
    const url = '/basic/v1/admin/namespaces/{namespace}/users/{userId}/profiles/status'.replace('{namespace}', this.namespace).replace('{userId}', userId)     
    const resultPromise = this.axiosInstance.patch(url, data, {params})

    return Validate.validateOrReturnResponse(this.useSchemaValidation, () => resultPromise, UserProfilePrivateInfo, 'UserProfilePrivateInfo')
  }
  
  /**
   * Get user custom attributes.&lt;br&gt;Other detail info: &lt;ul&gt;&lt;li&gt;&lt;i&gt;Returns&lt;/i&gt;: custom attributes&lt;/li&gt;&lt;li&gt;&lt;i&gt;Action code&lt;/i&gt;: 11403&lt;/li&gt;&lt;/ul&gt; 
   */
  getProfilesCustomAttributes_ByUserId(userId:string): Promise<Response<unknown>> {
    const params = {} as AxiosRequestConfig
    const url = '/basic/v1/admin/namespaces/{namespace}/users/{userId}/profiles/customAttributes'.replace('{namespace}', this.namespace).replace('{userId}', userId)     
    const resultPromise = this.axiosInstance.get(url, {params})

    return Validate.validateOrReturnResponse(this.useSchemaValidation, () => resultPromise, z.unknown(), 'z.unknown()')
  }
  
  /**
   * Update partially custom attributes tied to the user id.&lt;br&gt;Other detail info: &lt;ul&gt;&lt;li&gt;&lt;i&gt;Action code&lt;/i&gt;: 11402&lt;/li&gt;&lt;li&gt;&lt;i&gt;Request body&lt;/i&gt;: allowed format: JSON object&lt;/li&gt;&lt;li&gt;&lt;i&gt;Returns&lt;/i&gt;: Updated custom attributes&lt;/li&gt;&lt;/ul&gt; 
   */
  updateProfileCustomAttribute_ByUserId(userId:string, data: any): Promise<Response<unknown>> {
    const params = {} as AxiosRequestConfig
    const url = '/basic/v1/admin/namespaces/{namespace}/users/{userId}/profiles/customAttributes'.replace('{namespace}', this.namespace).replace('{userId}', userId)     
    const resultPromise = this.axiosInstance.put(url, data, {params})

    return Validate.validateOrReturnResponse(this.useSchemaValidation, () => resultPromise, z.unknown(), 'z.unknown()')
  }
  
  /**
   * Get user private custom attributes.&lt;br&gt;Other detail info: &lt;ul&gt;&lt;li&gt;&lt;i&gt;Returns&lt;/i&gt;: custom attributes&lt;/li&gt;&lt;li&gt;&lt;i&gt;Action code&lt;/i&gt;: 11403&lt;/li&gt;&lt;/ul&gt; 
   */
  getProfilesPrivateCustomAttributes_ByUserId(userId:string): Promise<Response<unknown>> {
    const params = {} as AxiosRequestConfig
    const url = '/basic/v1/admin/namespaces/{namespace}/users/{userId}/profiles/privateCustomAttributes'.replace('{namespace}', this.namespace).replace('{userId}', userId)     
    const resultPromise = this.axiosInstance.get(url, {params})

    return Validate.validateOrReturnResponse(this.useSchemaValidation, () => resultPromise, z.unknown(), 'z.unknown()')
  }
  
  /**
   * Update partially private custom attributes tied to the user id.&lt;br&gt;Other detail info: &lt;ul&gt;&lt;li&gt;&lt;i&gt;Action code&lt;/i&gt;: 11402&lt;/li&gt;&lt;li&gt;&lt;i&gt;Request body&lt;/i&gt;: allowed format: JSON object&lt;/li&gt;&lt;li&gt;&lt;i&gt;Returns&lt;/i&gt;: Updated custom attributes&lt;/li&gt;&lt;/ul&gt; 
   */
  updateProfilePrivateCustomAttribute_ByUserId(userId:string, data: any): Promise<Response<unknown>> {
    const params = {} as AxiosRequestConfig
    const url = '/basic/v1/admin/namespaces/{namespace}/users/{userId}/profiles/privateCustomAttributes'.replace('{namespace}', this.namespace).replace('{userId}', userId)     
    const resultPromise = this.axiosInstance.put(url, data, {params})

    return Validate.validateOrReturnResponse(this.useSchemaValidation, () => resultPromise, z.unknown(), 'z.unknown()')
  }
  
}
  